### =========================================================================
### The is.unsorted() generic
### -------------------------------------------------------------------------

setGeneric("is.unsorted", signature = "x")
